@@ -10,6 +10,8 @@ from neurohive.integration.unitycloud import UnityCloud
 from neurohive.integration.appcenter import AppCenter
 from neurohive.deploy.ecs import AwsEcsDeploy
 from ..deploy.compose_conv import convert_compose_to_vars
+from ..deploy.kube import prep_ustate_kube_versions
+from ..deploy.unity import update_unity_ios_creds
 
 
 def get_jira_name_from_branch(branch_name):
@@ -85,3 +87,31 @@ def prepare_compose_vars():
     parser.add_argument('--vars-file', type=str, required=True)
     args = parser.parse_args()
     convert_compose_to_vars(args.compose_file, args.vars_file)
+
+
+def prepare_ustate_kube_values():
+    parser = argparse.ArgumentParser()
+    parser.add_argument("--values-file", type=str, required=True)
+    parser.add_argument("--namespace", type=str, required=True)
+    args = parser.parse_args()
+    prep_ustate_kube_versions(args.namespace, args.values_file)
+
+
+def update_unity_creds():
+    parser = argparse.ArgumentParser()
+    parser.add_argument("--project", type=str, required=True, help="Unity CB Project Name")
+    parser.add_argument("--target", type=str, required=True, help="Unity CB Target Name")
+    parser.add_argument("--bundle", type=str, required=True, help="iOS bundle id")
+    parser.add_argument("--prov-type", type=str, required=True, help="iOS provision type")
+    args = parser.parse_args()
+    update_unity_ios_creds(args.project, args.target, args.bundle, args.prov_type)
+
+
+def get_ac_dl_link():
+    parser = argparse.ArgumentParser()
+    parser.add_argument("--owner", type=str, required=True)
+    parser.add_argument("--app", type=str, required=True)
+    parser.add_argument("--build-ver", type=str, required=True)
+    args = parser.parse_args()
+    ac = AppCenter(args.owner)
+    print(ac.get_download_link(args.app, args.build_ver))
